@@ -1,10 +1,10 @@
 #![allow(improper_ctypes)]
 
-use fluence::fce;
+use fluence::marine;
 
 pub fn main() {}
 
-#[fce]
+#[marine]
 pub fn all_types(
     _arg_0: i8,
     _arg_1: i16,
@@ -22,57 +22,57 @@ pub fn all_types(
     unimplemented!()
 }
 
-#[fce]
+#[marine]
 pub fn string_type(_arg: String) -> String {
     unimplemented!()
 }
 
-#[fce]
+#[marine]
 pub fn str_type(_arg: &str) -> &str {
     unimplemented!()
 }
 
-#[fce]
+#[marine]
 pub fn bytearray_type(_arg: Vec<u8>) -> Vec<u8> {
     unimplemented!()
 }
 
-#[fce]
+#[marine]
 pub fn bool_type(_arg: bool) -> bool {
     unimplemented!()
 }
 
-#[fce]
+#[marine]
 pub fn f32_type(_arg: f32) -> f32 {
     unimplemented!()
 }
 
-#[fce]
+#[marine]
 pub fn f64_type(_arg: f64) -> f64 {
     unimplemented!()
 }
 
-#[fce]
+#[marine]
 pub fn u32_type(_arg: u32) -> u32 {
     unimplemented!()
 }
 
-#[fce]
+#[marine]
 pub fn u64_type(_arg: u64) -> u64 {
     unimplemented!()
 }
 
-#[fce]
+#[marine]
 pub fn i32_type(_arg: i32) -> i32 {
     unimplemented!()
 }
 
-#[fce]
+#[marine]
 pub fn i64_type(_arg: i64) -> i64 {
     unimplemented!()
 }
 
-#[fce]
+#[marine]
 pub fn empty_type() -> String {
     unimplemented!()
 }
